@@ -27,8 +27,6 @@ Config.set ('refer/mapping', {
     'K' : ('keywords', 1),
     'X' : ('abstract', 1),
     'W' : ('location', 1),
+    'F' : ('label', 1),
+    'O' : ('note', 1),
     })
-
-
-
-
