@@ -28,8 +28,17 @@ class SearchSelection (Iterator):
     def __init__ (self, search, iterator):
         self.search = search
         self.iter   = iterator
+	self.base = iterator.base
         return
 
+    def __iter__ (self):
+        test = self.search.match
+        for i in self.iter :
+            if test(i):
+                yield i
+        raise StopIteration
+    
+
 
     def first (self):
         entry = self.iter.first ()
@@ -63,20 +72,27 @@ class SortSelection (Iterator):
 
     def __init__ (self, sort, iterator):
         # compute asap
-        (self.keys, self.data)  = sort.sort (iterator)
+        self.data  = sort.sort (iterator)
+        self.base = iterator.base 
         self.count = 0
         return
 
+    def __iter__ (self):
+        self.count = 0
+        for i in self.data:
+            yield i
+            self.count += 1
+        raise StopIteration
+
     def first (self):
         self.count = 0
         return self.next ()
 
     def next (self):
         try:
-            ret = self.data [self.keys [self.count]]
+            ret = self.data [self.count]
         except IndexError:
             return None
-        
         self.count = self.count + 1
         return ret
     
