@@ -23,14 +23,12 @@
 version  = "@version@"
 progname = "@package@"
 
-lib_pybdir  = "@libpyb@"
 data_pybdir = "@datapyb@"
 localedir   = "@localedir@"
 
 import sys
 
 sys.path.insert (0, data_pybdir)
-sys.path.insert (0, lib_pybdir)
 sys.path.insert (0, '.')
 
 import locale
@@ -39,7 +37,7 @@ locale.setlocale (locale.LC_ALL, '')
 import gettext
 gettext.install (progname, localedir, unicode = True)
 
-charset = locale.getlocale () [1]
+charset = locale.getlocale () [1] or 'ascii'
 
 def print_version ():
 	print (_("This is %s, version %s") % (progname, version)).encode (charset)
